@@ -436,11 +436,10 @@ export function shimAddTrackRemoveTrackWithNative(window) {
     };
 }
 
-export function shimAddTrackRemoveTrack(window) {
+export function shimAddTrackRemoveTrack(window, browserDetails) {
   if (!window.RTCPeerConnection) {
     return;
   }
-  const browserDetails = utils.detectBrowser(window);
   // shim addTrack and removeTrack.
   if (window.RTCPeerConnection.prototype.addTrack &&
       browserDetails.version >= 65) {
@@ -663,9 +662,7 @@ export function shimAddTrackRemoveTrack(window) {
     };
 }
 
-export function shimPeerConnection(window) {
-  const browserDetails = utils.detectBrowser(window);
-
+export function shimPeerConnection(window, browserDetails) {
   if (!window.RTCPeerConnection && window.webkitRTCPeerConnection) {
     // very basic support for old versions.
     window.RTCPeerConnection = window.webkitRTCPeerConnection;
@@ -674,9 +671,6 @@ export function shimPeerConnection(window) {
     return;
   }
 
-  const addIceCandidateNullSupported =
-    window.RTCPeerConnection.prototype.addIceCandidate.length === 0;
-
   // shim implicit creation of RTCSessionDescription/RTCIceCandidate
   if (browserDetails.version < 53) {
     ['setLocalDescription', 'setRemoteDescription', 'addIceCandidate']
@@ -691,31 +685,10 @@ export function shimPeerConnection(window) {
           window.RTCPeerConnection.prototype[method] = methodObj[method];
         });
   }
-
-  // support for addIceCandidate(null or undefined)
-  const nativeAddIceCandidate =
-      window.RTCPeerConnection.prototype.addIceCandidate;
-  window.RTCPeerConnection.prototype.addIceCandidate =
-    function addIceCandidate() {
-      if (!addIceCandidateNullSupported && !arguments[0]) {
-        if (arguments[1]) {
-          arguments[1].apply(null);
-        }
-        return Promise.resolve();
-      }
-      // Firefox 68+ emits and processes {candidate: "", ...}, ignore
-      // in older versions. Native support planned for Chrome M77.
-      if (browserDetails.version < 78 &&
-        arguments[0] && arguments[0].candidate === '') {
-        return Promise.resolve();
-      }
-      return nativeAddIceCandidate.apply(this, arguments);
-    };
 }
 
 // Attempt to fix ONN in plan-b mode.
-export function fixNegotiationNeeded(window) {
-  const browserDetails = utils.detectBrowser(window);
+export function fixNegotiationNeeded(window, browserDetails) {
   utils.wrapPeerConnectionEvent(window, 'negotiationneeded', e => {
     const pc = e.target;
     if (browserDetails.version < 72 || (pc.getConfiguration &&
